@@ -2,7 +2,7 @@
 # @Author: Kelvin
 # @Date:   2020-05-18 00:15:00
 # @Last Modified by:   Kelvin
-# @Last Modified time: 2022-07-07 12:40:40
+# @Last Modified time: 2022-10-27 11:01:55
 """plotting module."""
 import matplotlib.patches as mpatches
 import matplotlib.pyplot as plt
@@ -14,6 +14,7 @@ from anndata import AnnData
 from itertools import combinations, cycle
 from matplotlib.axes import Axes
 from matplotlib.figure import Figure
+import networkx as nx
 from plotnine import (
     aes,
     geom_line,
@@ -32,11 +33,12 @@ from time import sleep
 from tqdm import tqdm
 from typing import Union, Sequence, Tuple, Dict, Optional
 
-
-from ..tools._diversity import rarefun
-from ..utilities._core import *
-from ..utilities._io import *
-from ..utilities._utilities import *
+import dandelion.external.nxviz as nxv
+from dandelion.external.nxviz import annotate
+from dandelion.tools._diversity import rarefun
+from dandelion.utilities._core import *
+from dandelion.utilities._io import *
+from dandelion.utilities._utilities import *
 
 
 def clone_rarefaction(
@@ -280,6 +282,7 @@ def barplot(
     normalize: bool = True,
     sort_descending: bool = True,
     title: Optional[str] = None,
+    xtick_fontsize: Optional[int] = None,
     xtick_rotation: Optional[Union[int, float]] = None,
     min_clone_size: Optional[int] = None,
     clone_key: Optional[str] = None,
@@ -309,6 +312,8 @@ def barplot(
         whether or not to sort the order of the plot. Default is True.
     title : str, Optional
         title of plot.
+    xtick_fontsize : int, Optional
+        size of x tick labels
     xtick_rotation : int, float, Optional
         rotation of x tick labels.
     min_clone_size : int, Optional
@@ -362,10 +367,15 @@ def barplot(
     else:
         ax.set_ylabel("count")
     ax.set_xlabel("")
+    # modify the x ticks accordingly
+    xtick_params = {}
     if xtick_rotation is None:
-        plt.xticks(rotation=90)
+        xtick_params["rotation"] = 90
     else:
-        plt.xticks(rotation=xtick_rotation)
+        xtick_params["rotation"] = xtick_rotation
+    if xtick_fontsize is not None:
+        xtick_params["fontsize"] = xtick_fontsize
+    plt.xticks(**xtick_params)
     return fig, ax
 
 
@@ -377,9 +387,14 @@ def stackedbarplot(
     normalize: bool = False,
     title: Optional[str] = None,
     sort_descending: bool = True,
+    xtick_fontsize: Optional[int] = None,
     xtick_rotation: Optional[Union[int, float]] = None,
-    hide_legend: bool = True,
-    legend_options: Tuple[str, Tuple[float, float], int] = None,
+    hide_legend: bool = False,
+    legend_options: Tuple[str, Tuple[float, float], int] = (
+        "upper left",
+        (1, 1),
+        1,
+    ),
     labels: Optional[Sequence] = None,
     min_clone_size: Optional[int] = None,
     clone_key: Optional[str] = None,
@@ -404,6 +419,8 @@ def stackedbarplot(
         whether or not to sort the order of the plot. Default is True.
     title : str, Optional
         title of plot.
+    xtick_fontsize : int, Optional
+        size of x tick labels
     xtick_rotation: Optional[Union[int,float]] : int, float, Optional
         rotation of x tick labels.
     hide_legend : bool
@@ -466,9 +483,10 @@ def stackedbarplot(
         labels: Optional[Sequence] = None,
         figsize: Tuple[Union[int, float], Union[int, float]] = (8, 3),
         title: str = "multiple stacked bar plot",
+        xtick_fontsize: Optional[int] = None,
         xtick_rotation: Optional[Union[int, float]] = None,
         legend_options: Tuple[str, Tuple[float, float], int] = None,
-        hide_legend: bool = True,
+        hide_legend: bool = False,
         H: Literal["/"] = "/",
         **kwargs,
     ) -> Tuple[Figure, Axes]:
@@ -550,10 +568,15 @@ def stackedbarplot(
                 )
                 ax.add_artist(l2)
             ax.add_artist(l1)
+        # modify the x ticks accordingly
+        xtick_params = {}
         if xtick_rotation is None:
-            plt.xticks(rotation=90)
+            xtick_params["rotation"] = 90
         else:
-            plt.xticks(rotation=xtick_rotation)
+            xtick_params["rotation"] = xtick_rotation
+        if xtick_fontsize is not None:
+            xtick_params["fontsize"] = xtick_fontsize
+        plt.xticks(**xtick_params)
 
         return fig, ax
 
@@ -569,6 +592,7 @@ def stackedbarplot(
         labels=labels,
         figsize=figsize,
         title=title,
+        xtick_fontsize=xtick_fontsize,
         xtick_rotation=xtick_rotation,
         legend_options=legend_options,
         hide_legend=hide_legend,
@@ -584,9 +608,14 @@ def spectratype(
     figsize: Tuple[Union[int, float], Union[int, float]] = (5, 3),
     width: Optional[Union[int, float]] = None,
     title: Optional[str] = None,
+    xtick_fontsize: Optional[int] = None,
     xtick_rotation: Optional[Union[int, float]] = None,
-    hide_legend: bool = True,
-    legend_options: Tuple[str, Tuple[float, float], int] = None,
+    hide_legend: bool = False,
+    legend_options: Tuple[str, Tuple[float, float], int] = (
+        "upper left",
+        (1, 1),
+        1,
+    ),
     labels: Optional[Sequence] = None,
     **kwargs,
 ) -> Tuple[Figure, Axes]:
@@ -609,6 +638,8 @@ def spectratype(
         width of bars.
     title : str, Optional
         title of plot.
+    xtick_fontsize : int, Optional
+        size of x tick labels
     xtick_rotation : int, float, Optional
         rotation of x tick labels.
     hide_legend : bool
@@ -660,9 +691,10 @@ def spectratype(
         figsize: Tuple[Union[int, float], Union[int, float]] = (5, 3),
         title: str = "multiple stacked bar plot",
         width: Optional[Union[int, float]] = None,
+        xtick_fontsize: Optional[int] = None,
         xtick_rotation: Optional[Union[int, float]] = None,
         legend_options: Tuple[str, Tuple[float, float], int] = None,
-        hide_legend: bool = True,
+        hide_legend: bool = False,
         H: Literal["/"] = "/",
         **kwargs,
     ) -> Tuple[Figure, Axes]:
@@ -737,10 +769,15 @@ def spectratype(
                     frameon=False,
                 )
             ax.add_artist(l1)
+        # modify the x ticks accordingly
+        xtick_params = {}
         if xtick_rotation is None:
-            plt.xticks(rotation=0)
+            xtick_params["rotation"] = 90
         else:
-            plt.xticks(rotation=xtick_rotation)
+            xtick_params["rotation"] = xtick_rotation
+        if xtick_fontsize is not None:
+            xtick_params["fontsize"] = xtick_fontsize
+        plt.xticks(**xtick_params)
 
         return fig, ax
 
@@ -750,6 +787,7 @@ def spectratype(
         figsize=figsize,
         title=title,
         width=width,
+        xtick_fontsize=xtick_fontsize,
         xtick_rotation=xtick_rotation,
         legend_options=legend_options,
         hide_legend=hide_legend,
@@ -779,9 +817,9 @@ def clone_overlap(
     **kwargs,
 ):
     """
-    A plot function to visualise clonal overlap as a circos-style plot. Requires nxviz.
+    A plot function to visualise clonal overlap as a circos-style plot.
 
-    Written with nxviz < 0.7.3. Will need to revisit for newer nxviz versions, or change how it's called?
+    Originally written with nxviz < 0.7.3. Ported from https://github.com/zktuong/nxviz/tree/custom_color_mapping_circos_nodes_and_edges
 
     Parameters
     ----------
@@ -821,18 +859,6 @@ def clone_overlap(
     -------
     a `nxviz.CircosPlot`.
     """
-    import networkx as nx
-
-    try:
-        import nxviz as nxv
-    except:
-        raise (
-            ImportError(
-                "Unable to import module `nxviz`. Have you done install nxviz? "
-                "Try pip install git+https://github.com/zktuong/nxviz.git@custom_color_mapping_circos_nodes_and_edges"
-            )
-        )
-
     if min_clone_size is None:
         min_size = 2
     else:
@@ -986,53 +1012,34 @@ def clone_overlap(
             .reset_index(drop=True)
         )
 
-    try:
-        from importlib.metadata import version
-
-        NXVIZVERSION = version("nxviz")
-    except:
-        try:
-            from pkg_resources import get_distribution
-
-            NXVIZVERSION = get_distribution("nxviz").version
-        except:
-            NXVIZVERSION = "0.7.4"  # just for local
-    if NXVIZVERSION < "0.7.4":
-        raise ImportError(
-            "please upgrade nxviz: "
-            "pip install git+https://github.com/zktuong/nxviz.git@custom_color_mapping_circos_nodes_and_edges"
-        )
+    if as_heatmap:
+        hm = nx.to_pandas_adjacency(G)
+        sns.clustermap(hm, **kwargs)
     else:
-        if as_heatmap:
-            hm = nx.to_pandas_adjacency(G)
-            sns.clustermap(hm, **kwargs)
-        else:
-            from nxviz import annotate
-
-            ax = nxv.circos(
+        ax = nxv.circos(
+            G,
+            group_by=colorby,
+            node_color_by=colorby,
+            edge_lw_by=weighted_attr,
+            node_palette=colorby_dict,
+        )  # group_by
+        if node_labels:
+            annotate.circos_group(
                 G,
                 group_by=colorby,
-                node_color_by=colorby,
-                edge_lw_by=weighted_attr,
-                node_palette=colorby_dict,
-            )  # group_by
-            if node_labels:
-                annotate.circos_group(
-                    G,
-                    group_by=colorby,
-                    midpoint=False,
-                    fontdict={"size": node_label_size},
-                )
-            annotate.node_colormapping(
-                G,
-                color_by=colorby,
-                palette=colorby_dict,
-                legend_kwargs=legend_kwargs,
+                midpoint=False,
+                fontdict={"size": node_label_size},
             )
-        if save is not None:
-            plt.savefig(save, bbox_inches="tight", **kwargs)
-        if return_graph:
-            return G
+        annotate.node_colormapping(
+            G,
+            color_by=colorby,
+            palette=colorby_dict,
+            legend_kwargs=legend_kwargs,
+        )
+    if save is not None:
+        plt.savefig(save, bbox_inches="tight", **kwargs)
+    if return_graph:
+        return G
 
 
 def productive_ratio(
