@@ -2,7 +2,7 @@
 # @Author: Kelvin
 # @Date:   2021-02-11 12:22:40
 # @Last Modified by:   Kelvin
-# @Last Modified time: 2022-07-06 08:58:11
+# @Last Modified time: 2022-11-08 15:24:59
 """core module."""
 import bz2
 import copy
@@ -31,8 +31,8 @@ from textwrap import dedent
 from tqdm import tqdm
 from typing import Union, Sequence, Dict, Optional, Tuple
 
-from ..utilities._io import *
-from ..utilities._utilities import *
+from dandelion.utilities._io import *
+from dandelion.utilities._utilities import *
 
 
 class Dandelion:
@@ -2178,8 +2178,12 @@ def initialize_metadata(
         ],
         ref_col="chain_status",
     )
-
-    self.metadata = tmp_metadata.copy()
+    # if metadata already exist, just overwrite the default columns?
+    if self.metadata is not None:
+        for col in tmp_metadata:
+            self.metadata[col] = pd.Series(tmp_metadata[col])
+    else:
+        self.metadata = tmp_metadata.copy()
 
 
 def update_metadata(
@@ -2198,7 +2202,7 @@ def update_metadata(
         "average",
     ] = "split and merge",
     collapse_alleles: bool = True,
-    reinitialize: bool = False,
+    reinitialize: bool = True,
     verbose: bool = False,
     by_celltype: bool = False,
 ) -> Dandelion:
@@ -2215,19 +2219,28 @@ def update_metadata(
         Column name of clone id. None defaults to 'clone_id'.
     retrieve_mode: str
         One of:
-            `split and unique only` returns the retrieval splitted into two columns,
-                i.e. one for VDJ and one for VJ chains, separated by '|' for unique elements.
-            `merge and unique only` returns the retrieval merged into one column,
-                separated by '|' for unique elements.
-            `split and merge` returns the retrieval splitted into two columns,
-                i.e. one for VDJ and one for VJ chains, separated by '|' for every elements.
-            `split` returns the retrieval splitted into separate columns for each contig.
-            `merge` returns the retrieval merged into one columns for each contig,
-                separated by '|' for unique elements.
-            'split and sum' returns the retrieval sumed in the VDJ and VJ columns (separately).
-            'split and average' returns the retrieval averaged in the VDJ and VJ columns (separately).
-            'sum' returns the retrieval sumed into one column for all contigs.
-            'average' returns the retrieval averaged into one column for all contigs.
+            `split and unique only`
+                returns the retrieval splitted into two columns,
+                i.e. one for VDJ and one for VJ chains, separated by `|` for unique elements.
+            `merge and unique only`
+                returns the retrieval merged into one column,
+                separated by `|` for unique elements.
+            `split and merge`
+                returns the retrieval splitted into two columns,
+                i.e. one for VDJ and one for VJ chains, separated by `|` for every elements.
+            `split`
+                returns the retrieval splitted into separate columns for each contig.
+            `merge`
+                returns the retrieval merged into one columns for each contig,
+                separated by `|` for unique elements.
+            `split and sum`
+                returns the retrieval sumed in the VDJ and VJ columns (separately).
+            `split and average`
+                returns the retrieval averaged in the VDJ and VJ columns (separately).
+            `sum`
+                returns the retrieval sumed into one column for all contigs.
+            `average`
+                returns the retrieval averaged into one column for all contigs.
     collapse_alleles : bool
         Returns the V(D)J genes with allelic calls if False.
     reinitialize : bool
@@ -2235,7 +2248,8 @@ def update_metadata(
         Useful when updating older versions of `dandelion` to newer version.
     Returns
     -------
-    `Dandelion` object with `.metadata` slot initialized.
+    Dandelion
+        `Dandelion` object with `.metadata` slot initialized.
     """
 
     if clone_key is None:
